# How to use
Download the script by either cloning this repo:
`git clone https://github.com/spirosbax/openCoursesDownloader`
or hit the green download button on the top right.

Run the script using:
`python3 [path to script]`

Enter the subject code of an open subject, eg. DDI101
Then all the files that are not in a folder will be downloaded on the directory from which you ran the script.

# Limitations
This script currently only works for open subjects and downloads only files that are not in folders.

# Contribute
This project is a very good starting point for python web scraping.
If you want to contribute just fork this repo and start.

## Similar projects
[Gram Scanner](https://github.com/nickgarlis/gram-scanner)
